Scientific papers datasets contains two sets of long and structured documents.
The datasets are obtained from ArXiv and PubMed OpenAccess repositories.

Both "arxiv" and "pubmed" have two features:

-   article: the body of the document, pagragraphs seperated by "/n".
-   abstract: the abstract of the document, pagragraphs seperated by "/n".
-   section_names: titles of sections, seperated by "/n".
